diff --git a/Control/CalypsoExample/Digitization/scripts/faser_digi_merge.py b/Control/CalypsoExample/Digitization/scripts/faser_digi_merge.py
index 2854fd9932e0b6e561020984bac57b8b1f39b86c..a99c51eecdc4a813901085de67d792be40f73cb6 100755
--- a/Control/CalypsoExample/Digitization/scripts/faser_digi_merge.py
+++ b/Control/CalypsoExample/Digitization/scripts/faser_digi_merge.py
@@ -131,7 +131,7 @@ if len(args.short) > 0:
 # more files later.  --complete overrides this if wanted
 
 # Build output filename
-if seglo == 0 and (seghi+1) == len(dirlist) and args.complete:  # Full run
+if args.complete and (seglo == 0) and ((seghi+1) == len(dirlist)):  # Full run
     outfile = f"FaserMC-{short}-{run}"
 elif seglo == seghi:  # Single segment
     outfile = f"FaserMC-{short}-{run}-{seglo:05}"
diff --git a/PhysicsAnalysis/NtupleDumper/scripts/faser_ntuple_maker.py b/PhysicsAnalysis/NtupleDumper/scripts/faser_ntuple_maker.py
index 5ae87306e068ac7ebfde95f0c29aed5dba283f43..189b9500edf9244407789817a9e841405c0139f0 100755
--- a/PhysicsAnalysis/NtupleDumper/scripts/faser_ntuple_maker.py
+++ b/PhysicsAnalysis/NtupleDumper/scripts/faser_ntuple_maker.py
@@ -92,7 +92,7 @@ if filepath.is_dir():
     for seg in seglist:
 
         if args.isMC:
-            searchstr = f"FaserMC-*-{runstr}-{seg}-*xAOD.root"
+            searchstr = f"FaserMC-*-{seg}-*xAOD.root"
         else:
             searchstr = f"Faser-Physics-{runstr}-{seg}-*xAOD.root"
diff --git a/Control/CalypsoExample/Reconstruction/scripts/submit_faser_reco.sh b/Control/CalypsoExample/Reconstruction/scripts/submit_faser_reco.sh
index 5f1ee06615cd822c911cc67d0acc7659662e78dc..f75b144a1bf2d0a725692dbaa82be34ad788cd5c 100755
--- a/Control/CalypsoExample/Reconstruction/scripts/submit_faser_reco.sh
+++ b/Control/CalypsoExample/Reconstruction/scripts/submit_faser_reco.sh
@@ -11,7 +11,7 @@
 #
 # Monte Carlo options:
 #   --isMC - needed for MC reco
 #   --digiTag <tag> - override MC reco tag for calo gain (matches digi tag)
 # 
 # file_path - full file name (with path)
 # release_directory - optional path to release install directory (default pwd)
@@ -55,7 +55,7 @@ do
 	  ismc=1
 	  shift;;
 
-      --digiTag)
+      --caloTag)
 	  echo "Override calo digi tag with $2"
 	  gainstr="--MC_calibTag $2"
 	  shift;
@@ -11,7 +11,7 @@
 # Monte Carlo options:
 #   --isMC - needed for MC reco
-#   --digiTag <tag> - override MC reco tag for calo gain (matches digi tag)
+#   --caloTag <tag> - override MC reco tag for calo gain (to match digi tag)
 # 
 # file_path - full file name (with path)